Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1642)

Unified Diff: content/browser/renderer_host/input/gesture_event_filter_unittest.cc

Issue 40913002: Reenable the tap down gesture. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Freshen Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/renderer_host/input/gesture_event_filter.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/renderer_host/input/gesture_event_filter_unittest.cc
diff --git a/content/browser/renderer_host/input/gesture_event_filter_unittest.cc b/content/browser/renderer_host/input/gesture_event_filter_unittest.cc
index 0234fd9340b8d05914b3debb9f8dab2bf0539988..971fcf1d5cb060bae9c9a4b38c810cdd931d39f0 100644
--- a/content/browser/renderer_host/input/gesture_event_filter_unittest.cc
+++ b/content/browser/renderer_host/input/gesture_event_filter_unittest.cc
@@ -570,8 +570,8 @@ INSTANTIATE_TEST_CASE_P(AllSources,
WebGestureEvent::Touchpad));
#endif // GTEST_HAS_PARAM_TEST
-// Test that GestureShowPress events don't wait for ACKs.
-TEST_F(GestureEventFilterTest, GestureShowPressIgnoresAck) {
+// Test that GestureShowPress and GestureTapDown events don't wait for ACKs.
+TEST_F(GestureEventFilterTest, GestureShowPressAndTapDownIgnoreAck) {
SimulateGestureEvent(WebInputEvent::GestureShowPress,
WebGestureEvent::Touchscreen);
@@ -588,7 +588,14 @@ TEST_F(GestureEventFilterTest, GestureShowPressIgnoresAck) {
WebGestureEvent::Touchscreen);
EXPECT_EQ(1U, GetAndResetSentGestureEventCount());
- // The show press events will have escaped the queue, since they ignore acks.
+ EXPECT_EQ(0U, GestureEventLastQueueEventSize());
+
+ SimulateGestureEvent(WebInputEvent::GestureTapDown,
+ WebGestureEvent::Touchscreen);
+
+ EXPECT_EQ(1U, GetAndResetSentGestureEventCount());
+ // The show press and tap down events will have escaped the queue, since they
+ // ignore acks.
EXPECT_EQ(0U, GestureEventLastQueueEventSize());
}
« no previous file with comments | « content/browser/renderer_host/input/gesture_event_filter.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698